@@ -1,6 +1,7 @@
 import spacy
 import pattern.en as en
 from spacy.matcher import Matcher
+from pattern.en import lexeme
 
 noundict = {
     "i": "me",
@@ -26,6 +27,16 @@ def nouninv(noun):
     return noun
 
 
+def pattern_stopiteration_workaround():
+    try:
+        print(lexeme("check"))
+    except:
+        pass
+
+
+pattern_stopiteration_workaround()
+
+
 def pass2act(doc, rec=False):
     """
     Author : Daniel Nohimovich & Zhekai Jin (Scott)
